@@ -39,7 +39,7 @@ use Net::SolarWinds::Log;
 use JSON qw();
 use URI::Encode qw(uri_encode);
 
-our $VERSION=0.11;
+our $VERSION=1.12;
 
 use base qw(Net::SolarWinds::ConstructorHash Net::SolarWinds::LogMethods Net::SolarWinds::Helper);
 use constant RESULT_CLASS=>'Net::SolarWinds::Result';
@@ -469,20 +469,66 @@ sub NodeCustomProperties {
 
 =item * my $result=$self->Query($sql);
 
+=item * my $result=$self->Query({"query"=>"SELECT Uri FROM Orion.Pollers WHERE PollerID=@p ORDER BY PollerID WITH ROWS 1 TO 3 WITH TOTALROWS","parameters"=>{"p"=>9}});
+
 Used to run an sql query against CPM.
 Returns a Net::SolarWinds::Result Object: When true it contains the results, when false it contains the error.
 
+
+
 =cut
 
 sub Query {
   my ($self,$sql)=@_;
   $self->log_info("starting");
-  $self->log_debug("$sql");
-  my $path='Query?query='.uri_encode($sql);
-  my $request=$self->build_request('GET',$path);
+  my $result;
+  if(ref($sql) and ref($sql) eq 'HASH') {
+    $self->log_info("called in post mode");
+    $self->log_debug(Dumper($sql));
+    my $path='Query';
+    my $request=$self->build_request('POST',$path,$sql);
+    $result=$self->run_request($request);
+  } else {
+    $self->log_info("called in get mode");
+    $self->log_debug("$sql");
+    my $path='Query?query='.uri_encode($sql);
+    my $request=$self->build_request('GET',$path);
+    $result=$self->run_request($request);
+    $self->log_info("stopping");
+  }
+  return $result;
+}
+
+=item * my $result=$self->BulkUpdate({uris=>["swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=1", "swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=2", "swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=3"],properties=>{"NextPoll"=>"7/1/2014 9:06:19 AM","NextRediscovery"=>"7/1/2014 2:59:09 PM"}}); 
+
+Used to update uris in bulk, returns a Net::SolarWinds::Result object.
+
+=cut
+
+sub BulkUpdate {
+  my ($self,$ref)=@_;
+  $self->log_info("starting");
+  my $request=$self->build_request('POST','BulkUpdate',$ref);
   my $result=$self->run_request($request);
   $self->log_info("stopping");
-  return $result;
+
+  return $result
+}
+
+=item * my $result=$self->BulkDelete({uris=>["swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=1", "swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=2", "swis://dev-che-mjag-01./Orion/Orion.Nodes/NodeID=4/Volumes/VolumeID=3"]}); 
+
+Used to delete uris in bulk, returns a Net::SolarWinds::Result object.
+
+=cut
+
+sub BulkDelete {
+  my ($self,$ref)=@_;
+  $self->log_info("starting");
+  my $request=$self->build_request('POST','BulkDelete',$ref);
+  my $result=$self->run_request($request);
+  $self->log_info("stopping");
+
+  return $result
 }
 
 =item * my $result=$self->getNodesByIp($ip);
